AggregationResult class final

The result of a single bucket from a Firestore aggregation query.

The keys of aggregate_fields are the same for all results in an aggregation query, unlike document queries which can have different fields present for each result.

Constructors

AggregationResult({Map<String, Value> aggregateFields = const {}})
AggregationResult.fromJson(Object? j)
factory

Properties

aggregateFields Map<String, Value>
The result of the aggregation functions, ex: COUNT(*) AS total_docs.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String