BatchWriteRequest class final

The request for Firestore.BatchWrite.

Constructors

BatchWriteRequest({required String database, List<Write> writes = const [], Map<String, String> labels = const {}, RequestOptions? requestOptions})
BatchWriteRequest.fromJson(Object? j)
factory

Properties

database String
Required. The database name. In the format: projects/{project_id}/databases/{database_id}.
final
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>
Labels associated with this batch write.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestOptions RequestOptions?
Optional. Any additional options for the request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writes List<Write>
The writes to apply.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String