BeginTransactionRequest class final

The request for Firestore.BeginTransaction.

Constructors

BeginTransactionRequest({required String database, TransactionOptions? options})
BeginTransactionRequest.fromJson(Object? j)
factory

Properties

database String
Required. The database name. In the format: projects/{project_id}/databases/{database_id}.
final
hashCode int
The hash code for this object.
no setterinherited
options TransactionOptions?
The options for the transaction. Defaults to a read-write transaction.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String