CreateDocumentRequest class final

The request for Firestore.CreateDocument.

Constructors

CreateDocumentRequest({required String parent, required String collectionId, String documentId = '', required Document? document, DocumentMask? mask})
CreateDocumentRequest.fromJson(Object? j)
factory

Properties

collectionId String
Required. The collection ID, relative to parent, to list. For example: chatrooms.
final
document Document?
Required. The document to create. name must not be set.
final
documentId String
The client-assigned document ID to use for this document.
final
hashCode int
The hash code for this object.
no setterinherited
mask DocumentMask?
The fields to return. If not set, returns all fields.
final
parent String
Required. The parent resource. For example: projects/{project_id}/databases/{database_id}/documents or projects/{project_id}/databases/{database_id}/documents/chatrooms/{chatroom_id}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String