Cursor class final

A position in a query result set.

Constructors

Cursor({List<Value> values = const [], bool before = false})
Cursor.fromJson(Object? j)
factory

Properties

before bool
If the position is just before or just after the given values, relative to the sort order defined by the query.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<Value>
The values that represent a position, in the order they appear in the order by clause of a query.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String