before property
If the position is just before or just after the given values, relative to the sort order defined by the query.
Implementation
final bool before;
If the position is just before or just after the given values, relative to the sort order defined by the query.
final bool before;