Document class final

A Firestore document.

Must not exceed 1 MiB - 4 bytes.

Constructors

Document({String name = '', Map<String, Value> fields = const {}, Timestamp? createTime, Timestamp? updateTime})
Document.fromJson(Object? j)
factory

Properties

createTime → Timestamp?
Output only. The time at which the document was created.
final
fields Map<String, Value>
The document's fields.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The resource name of the document, for example projects/{project_id}/databases/{database_id}/documents/{document_path}.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTime → Timestamp?
Output only. The time at which the document was last changed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String