document property
The new state of the Document.
If mask is set, contains only fields that were updated or added.
Implementation
final Document? document;
The new state of the Document.
If mask is set, contains only fields that were updated or added.
final Document? document;