DocumentDelete class final

A Document has been deleted.

May be the result of multiple writes, including updates, the last of which deleted the Document.

Multiple DocumentDelete messages may be returned for the same logical delete, if multiple targets are affected.

Constructors

DocumentDelete({String document = '', List<int> removedTargetIds = const [], Timestamp? readTime})
DocumentDelete.fromJson(Object? j)
factory

Properties

document String
The resource name of the Document that was deleted.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readTime → Timestamp?
The read timestamp at which the delete was observed.
final
removedTargetIds List<int>
A set of target IDs for targets that previously matched this entity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String