DocumentTransform class final
A transformation of a document.
Constructors
-
DocumentTransform({String document = '', List<
DocumentTransform_FieldTransform> fieldTransforms = const []}) - DocumentTransform.fromJson(Object? j)
-
factory
Properties
- document → String
-
The name of the document to transform.
final
-
fieldTransforms
→ List<
DocumentTransform_FieldTransform> -
The list of transformations to apply to the fields of the document, in
order.
This must not be empty.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String