fieldTransforms property
The list of transformations to apply to the fields of the document, in order. This must not be empty.
Implementation
final List<DocumentTransform_FieldTransform> fieldTransforms;
The list of transformations to apply to the fields of the document, in order. This must not be empty.
final List<DocumentTransform_FieldTransform> fieldTransforms;