DocumentTransform_FieldTransform class final

A transformation of a field of the document.

Constructors

DocumentTransform_FieldTransform({String fieldPath = '', DocumentTransform_FieldTransform_ServerValue? setToServerValue, Value? increment, Value? maximum, Value? minimum, ArrayValue? appendMissingElements, ArrayValue? removeAllFromArray})
DocumentTransform_FieldTransform.fromJson(Object? j)
factory

Properties

appendMissingElements ArrayValue?
Append the given elements in order if they are not already present in the current field value. If the field is not an array, or if the field does not yet exist, it is first set to the empty array.
final
fieldPath String
The path of the field. See Document.fields for the field path syntax reference.
final
hashCode int
The hash code for this object.
no setterinherited
increment Value?
Adds the given value to the field's current value.
final
maximum Value?
Sets the field to the maximum of its current value and the given value.
final
minimum Value?
Sets the field to the minimum of its current value and the given value.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
removeAllFromArray ArrayValue?
Remove all of the given elements from the array in the field. If the field is not an array, or if the field does not yet exist, it is set to the empty array.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setToServerValue DocumentTransform_FieldTransform_ServerValue?
Sets the field to the given server value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String