DocumentTransform_FieldTransform_ServerValue class final

A value that is calculated by the server.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const DocumentTransform_FieldTransform_ServerValue
The default value for DocumentTransform_FieldTransform_ServerValue.
requestTime → const DocumentTransform_FieldTransform_ServerValue
The time at which the server processed the request, with millisecond precision. If used on multiple fields (same or different documents) in a transaction, all the fields will get the same server timestamp.
serverValueUnspecified → const DocumentTransform_FieldTransform_ServerValue
Unspecified. This value must not be used.