newTransaction property

TransactionOptions? newTransaction
final

Execute the pipeline in a new transaction.

The identifier of the newly created transaction will be returned in the first response on the stream. This defaults to a read-only transaction.

Implementation

final TransactionOptions? newTransaction;