readTime property

Timestamp? readTime
final

Execute the pipeline in a snapshot transaction at the given time.

This must be a microsecond precision timestamp within the past one hour, or if Point-in-Time Recovery is enabled, can additionally be a whole minute timestamp within the past 7 days.

Implementation

final Timestamp? readTime;