explainStats property
Query explain stats.
This is present on the last response if the request configured explain
to run in 'analyze' or 'explain' mode in the pipeline options. If the query
does not return any results, a response with explain_stats and no
results will still be sent.
Implementation
final ExplainStats? explainStats;