ExplainMetrics class final

Explain metrics for the query.

Constructors

ExplainMetrics({PlanSummary? planSummary, ExecutionStats? executionStats})
ExplainMetrics.fromJson(Object? j)
factory

Properties

executionStats ExecutionStats?
Aggregated stats from the execution of the query. Only present when ExplainOptions.analyze is set to true.
final
hashCode int
The hash code for this object.
no setterinherited
planSummary PlanSummary?
Planning phase information for the query.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String