analyze property

bool analyze
final

Optional. Whether to execute this query.

When false (the default), the query will be planned, returning only metrics from the planning stages.

When true, the query will be planned and executed, returning the full query results along with both planning and execution stage metrics.

Implementation

final bool analyze;