ExplainStats class final

Pipeline explain stats.

Depending on the explain options in the original request, this can contain the optimized plan and / or execution stats.

Constructors

ExplainStats({Any? data})
ExplainStats.fromJson(Object? j)
factory

Properties

data → Any?
The format depends on the output_format options in the request.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String