Firestore class final

The Cloud Firestore service.

Cloud Firestore is a fast, fully managed, serverless, cloud-native NoSQL document database that simplifies storing, syncing, and querying data for your mobile, web, and IoT apps at global scale. Its client libraries provide live synchronization and offline support, while its security features and integrations with Firebase and Google Cloud Platform accelerate building truly serverless apps.

Implementers

Constructors

Firestore({required Client client, Uri? endPoint})
Creates a Firestore using client for transport.
Firestore.fromApiKey([String? apiKey])
Creates a Firestore that does authentication through an API key.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchGetDocuments(BatchGetDocumentsRequest request) Stream<BatchGetDocumentsResponse>
Gets multiple documents.
batchWrite(BatchWriteRequest request) Future<BatchWriteResponse>
Applies a batch of write operations.
beginTransaction(BeginTransactionRequest request) Future<BeginTransactionResponse>
Starts a new transaction.
cancelOperation(CancelOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
close() → void
Closes the client and cleans up any resources associated with it.
commit(CommitRequest request) Future<CommitResponse>
Commits a transaction, while optionally updating documents.
createDocument(CreateDocumentRequest request) Future<Document>
Creates a new document.
deleteDocument(DeleteDocumentRequest request) Future<void>
Deletes a document.
deleteOperation(DeleteOperationRequest request) Future<void>
Provides the Operations service functionality in this service.
executePipeline(ExecutePipelineRequest request) Stream<ExecutePipelineResponse>
Executes a pipeline query.
getDocument(GetDocumentRequest request) Future<Document>
Gets a single document.
getOperation<T extends ProtoMessage, S extends ProtoMessage>(Operation<T, S> request) Future<Operation<T, S>>
Provides the Operations service functionality in this service.
listCollectionIds(ListCollectionIdsRequest request) Future<ListCollectionIdsResponse>
Lists all the collection IDs underneath a document.
listDocuments(ListDocumentsRequest request) Future<ListDocumentsResponse>
Lists documents.
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Provides the Operations service functionality in this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partitionQuery(PartitionQueryRequest request) Future<PartitionQueryResponse>
Partitions a query by returning partition cursors that can be used to run the query in parallel. The returned partition cursors are split points that can be used by RunQuery as starting/end points for the query results.
rollback(RollbackRequest request) Future<void>
Rolls back a transaction.
runAggregationQuery(RunAggregationQueryRequest request) Stream<RunAggregationQueryResponse>
Runs an aggregation query.
runQuery(RunQueryRequest request) Stream<RunQueryResponse>
Runs a query.
toString() String
A string representation of this object.
inherited
updateDocument(UpdateDocumentRequest request) Future<Document>
Updates or inserts a document.

Operators

operator ==(Object other) bool
The equality operator.
inherited