Function$ class final

Represents an unevaluated scalar expression.

For example, the expression like(user_name, "%alice%") is represented as:

name: "like"
args { field_reference: "user_name" }
args { string_value: "%alice%" }

Constructors

Function$({required String name, List<Value> args = const [], Map<String, Value> options = const {}})
Function$.fromJson(Object? j)
factory

Properties

args List<Value>
Optional. Ordered list of arguments the given function expects.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Required. The name of the function to evaluate.
final
options Map<String, Value>
Optional. Optional named arguments that certain functions may support.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String