ListCollectionIdsRequest class final

The request for Firestore.ListCollectionIds.

Constructors

ListCollectionIdsRequest({required String parent, int pageSize = 0, String pageToken = '', Timestamp? readTime})
ListCollectionIdsRequest.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pageSize int
The maximum number of results to return.
final
pageToken String
A page token. Must be a value from ListCollectionIdsResponse.
final
parent String
Required. The parent document. In the format: projects/{project_id}/databases/{database_id}/documents/{document_path}. For example: projects/my-project/databases/my-database/documents/chatrooms/my-chatroom
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readTime → Timestamp?
Reads documents as they were at the given time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String