ListDocumentsRequest class final

The request for Firestore.ListDocuments.

Constructors

ListDocumentsRequest({required String parent, String collectionId = '', int pageSize = 0, String pageToken = '', String orderBy = '', DocumentMask? mask, Uint8List? transaction, Timestamp? readTime, bool showMissing = false})
ListDocumentsRequest.fromJson(Object? j)
factory

Properties

collectionId String
Optional. The collection ID, relative to parent, to list.
final
hashCode int
The hash code for this object.
no setterinherited
mask DocumentMask?
Optional. The fields to return. If not set, returns all fields.
final
orderBy String
Optional. The optional ordering of the documents to return.
final
pageSize int
Optional. The maximum number of documents to return in a single response.
final
pageToken String
Optional. A page token, received from a previous ListDocuments response.
final
parent String
Required. The parent resource name. In the format: projects/{project_id}/databases/{database_id}/documents or projects/{project_id}/databases/{database_id}/documents/{document_path}.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readTime → Timestamp?
Perform the read at the provided time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showMissing bool
If the list should show missing documents.
final
transaction Uint8List?
Perform the read as part of an already active transaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String