collectionId property

String collectionId
final

Optional. The collection ID, relative to parent, to list.

For example: chatrooms or messages.

This is optional, and when not provided, Firestore will list documents from all collections under the provided parent.

Implementation

final String collectionId;