mask property

DocumentMask? mask
final

Optional. The fields to return. If not set, returns all fields.

If a document has a field that is not present in this mask, that field will not be returned in the response.

Implementation

final DocumentMask? mask;