showMissing property

bool showMissing
final

If the list should show missing documents.

A document is missing if it does not exist, but there are sub-documents nested underneath it. When true, such missing documents will be returned with a key but will not have fields, google.firestore.v1.Document.create_time, or google.firestore.v1.Document.update_time set.

Requests with show_missing may not specify where or order_by.

Implementation

final bool showMissing;