nextPageToken property
A token to retrieve the next page of documents.
If this field is omitted, there are no subsequent pages.
Implementation
final String nextPageToken;
A token to retrieve the next page of documents.
If this field is omitted, there are no subsequent pages.
final String nextPageToken;