nextPageToken property

String nextPageToken
final

A page token that may be used to request an additional set of results, up to the number specified by partition_count in the PartitionQuery request. If blank, there are no more results.

Implementation

final String nextPageToken;