PlanSummary class final

Planning phase information for the query.

Constructors

PlanSummary({List<Struct> indexesUsed = const []})
PlanSummary.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
indexesUsed List<Struct>
The indexes selected for the query. For example: {"query_scope": "Collection", "properties": "(foo ASC, __name__ ASC)"}, {"query_scope": "Collection", "properties": "(bar ASC, __name__ ASC)"}
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String