newTransaction property

TransactionOptions? newTransaction
final

Starts a new transaction as part of the query, defaulting to read-only.

The new transaction ID will be returned as the first response in the stream.

Implementation

final TransactionOptions? newTransaction;