transaction property

Uint8List transaction
final

The transaction that was started as part of this request.

Only present on the first response when the request requested to start a new transaction.

Implementation

final Uint8List transaction;