RunQueryRequest class final

The request for Firestore.RunQuery.

Constructors

RunQueryRequest({required String parent, StructuredQuery? structuredQuery, Uint8List? transaction, TransactionOptions? newTransaction, Timestamp? readTime, ExplainOptions? explainOptions})
RunQueryRequest.fromJson(Object? j)
factory

Properties

explainOptions ExplainOptions?
Optional. Explain options for the query. If set, additional query statistics will be returned. If not, only query results will be returned.
final
hashCode int
The hash code for this object.
no setterinherited
newTransaction TransactionOptions?
Starts a new transaction and reads the documents. Defaults to a read-only transaction. The new transaction ID will be returned as the first response in the stream.
final
parent String
Required. The parent resource name. In the format: projects/{project_id}/databases/{database_id}/documents or projects/{project_id}/databases/{database_id}/documents/{document_path}. For example: projects/my-project/databases/my-database/documents or projects/my-project/databases/my-database/documents/chatrooms/my-chatroom
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readTime → Timestamp?
Reads documents as they were at the given time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
structuredQuery StructuredQuery?
A structured query.
final
transaction Uint8List?
Run the query within an already active transaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String