RunQueryResponse class final

The response for Firestore.RunQuery.

Constructors

RunQueryResponse({Uint8List? transaction, Document? document, Timestamp? readTime, int skippedResults = 0, bool? done, ExplainMetrics? explainMetrics})
RunQueryResponse.fromJson(Object? j)
factory

Properties

document Document?
A query result, not set when reporting partial progress.
final
done bool?
If present, Firestore has completely finished the request and no more documents will be returned.
final
explainMetrics ExplainMetrics?
Query explain metrics. This is only present when the RunQueryRequest.explain_options is provided, and it is sent only once with the last response in the stream.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readTime → Timestamp?
The time at which the document was read. This may be monotonically increasing; in this case, the previous documents in the result stream are guaranteed not to have changed between their read_time and this one.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedResults int
The number of results that have been skipped due to an offset between the last response and the current response.
final
transaction Uint8List
The transaction that was started as part of this request. Can only be set in the first response, and only if RunQueryRequest.new_transaction was set in the request. If set, no other fields will be set in this response.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String