explainMetrics property
Query explain metrics. This is only present when the
RunQueryRequest.explain_options
is provided, and it is sent only once with the last response in the stream.
Implementation
final ExplainMetrics? explainMetrics;
Query explain metrics. This is only present when the
RunQueryRequest.explain_options
is provided, and it is sent only once with the last response in the stream.
final ExplainMetrics? explainMetrics;