readTime property

Timestamp? readTime
final

The time at which the document was read. This may be monotonically increasing; in this case, the previous documents in the result stream are guaranteed not to have changed between their read_time and this one.

If the query returns no results, a response with read_time and no document will be sent, and this represents the time at which the query was run.

Implementation

final Timestamp? readTime;