skippedResults property
The number of results that have been skipped due to an offset between the last response and the current response.
Implementation
final int skippedResults;
The number of results that have been skipped due to an offset between the last response and the current response.
final int skippedResults;