transaction property

Uint8List transaction
final

The transaction that was started as part of this request. Can only be set in the first response, and only if RunQueryRequest.new_transaction was set in the request. If set, no other fields will be set in this response.

Implementation

final Uint8List transaction;