StructuredAggregationQuery_Aggregation class final

Defines an aggregation that produces a single result.

Properties

alias String
Optional. Optional name of the field to store the result of the aggregation into.
final
avg StructuredAggregationQuery_Aggregation_Avg?
Average aggregator.
final
count StructuredAggregationQuery_Aggregation_Count?
Count aggregator.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sum StructuredAggregationQuery_Aggregation_Sum?
Sum aggregator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String