StructuredAggregationQuery_Aggregation_Avg class final
Average of the values of the requested field.
-
Only numeric values will be aggregated. All non-numeric values including
NULLare skipped. -
If the aggregated values contain
NaN, returnsNaN. Infinity math follows IEEE-754 standards. -
If the aggregated value set is empty, returns
NULL. -
Always returns the result as a double.
Constructors
Properties
- field → StructuredQuery_FieldReference?
-
The field to aggregate on.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String