StructuredPipeline class final
A Firestore query represented as an ordered list of operations / stages.
This is considered the top-level function which plans and executes a query.
It is logically equivalent to query(stages, options), but prevents the
client from having to build a function wrapper.
Constructors
-
StructuredPipeline({required Pipeline? pipeline, Map<
String, Value> options = const {}}) - StructuredPipeline.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ Map<
String, Value> -
Optional. Optional query-level arguments.
final
- pipeline → Pipeline?
-
Required. The pipeline query to execute.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String