StructuredQuery class final

A Firestore query.

The query stages are executed in the following order:

  1. from
  2. where
  3. select
  4. order_by + start_at + end_at
  5. offset
  6. limit
  7. find_nearest

Constructors

StructuredQuery({StructuredQuery_Projection? select, List<StructuredQuery_CollectionSelector> from = const [], StructuredQuery_Filter? where, List<StructuredQuery_Order> orderBy = const [], Cursor? startAt, Cursor? endAt, int offset = 0, Int32Value? limit, StructuredQuery_FindNearest? findNearest})
StructuredQuery.fromJson(Object? j)
factory

Properties

endAt Cursor?
A potential prefix of a position in the result set to end the query at.
final
findNearest StructuredQuery_FindNearest?
Optional. A potential nearest neighbors search.
final
from List<StructuredQuery_CollectionSelector>
The collections to query.
final
hashCode int
The hash code for this object.
no setterinherited
limit → Int32Value?
The maximum number of results to return.
final
offset int
The number of documents to skip before returning the first result.
final
orderBy List<StructuredQuery_Order>
The order to apply to the query results.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
select StructuredQuery_Projection?
Optional sub-set of the fields to return.
final
startAt Cursor?
A potential prefix of a position in the result set to start the query at.
final
where StructuredQuery_Filter?
The filter to apply.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String