findNearest property
Optional. A potential nearest neighbors search.
Applies after all other filters and ordering.
Finds the closest vector embeddings to the given query vector.
Implementation
final StructuredQuery_FindNearest? findNearest;
Optional. A potential nearest neighbors search.
Applies after all other filters and ordering.
Finds the closest vector embeddings to the given query vector.
final StructuredQuery_FindNearest? findNearest;