allDescendants property
When false, selects only collections that are immediate children of
the parent specified in the containing RunQueryRequest.
When true, selects all descendant collections.
Implementation
final bool allDescendants;
When false, selects only collections that are immediate children of
the parent specified in the containing RunQueryRequest.
When true, selects all descendant collections.
final bool allDescendants;