distanceResultField property
Optional. Optional name of the field to output the result of the vector
distance calculation. Must conform to google.firestore.v1.Document.fields limitations.
Implementation
final String distanceResultField;
Optional. Optional name of the field to output the result of the vector
distance calculation. Must conform to google.firestore.v1.Document.fields limitations.
final String distanceResultField;