StructuredQuery_Order class final
An order on a field.
Constructors
- StructuredQuery_Order({StructuredQuery_FieldReference? field, StructuredQuery_Direction direction = StructuredQuery_Direction.$default})
- StructuredQuery_Order.fromJson(Object? j)
-
factory
Properties
- direction → StructuredQuery_Direction
-
The direction to order by. Defaults to
ASCENDING.final - field → StructuredQuery_FieldReference?
-
The field to order by.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String