StructuredQuery_Projection class final
The projection of document's fields to return.
Constructors
-
StructuredQuery_Projection({List<
StructuredQuery_FieldReference> fields = const []}) - StructuredQuery_Projection.fromJson(Object? j)
-
factory
Properties
-
fields
→ List<
StructuredQuery_FieldReference> -
The fields to return.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String