Target class final

A specification of a set of documents to listen to.

Constructors

Target({Target_QueryTarget? query, Target_DocumentsTarget? documents, Uint8List? resumeToken, Timestamp? readTime, int targetId = 0, bool once = false, Int32Value? expectedCount})
Target.fromJson(Object? j)
factory

Properties

documents → Target_DocumentsTarget?
A target specified by a set of document names.
final
expectedCount → Int32Value?
The number of documents that last matched the query at the resume token or read time.
final
hashCode → int
The hash code for this object.
no setterinherited
once → bool
If the target should be removed once it is current and consistent.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
query → Target_QueryTarget?
A target specified by a query.
final
readTime → Timestamp?
Start listening after a specific read_time.
final
resumeToken → Uint8List?
A resume token from a prior TargetChange for an identical target.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId → int
The target ID that identifies the target on the stream. Must be a positive number and non-zero.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String