expectedCount property

Int32Value? expectedCount
final

The number of documents that last matched the query at the resume token or read time.

This value is only relevant when a resume_type is provided. This value being present and greater than zero signals that the client wants ExistenceFilter.unchanged_names to be included in the response.

Implementation

final Int32Value? expectedCount;