resumeToken property
A resume token from a prior
TargetChange for an identical target.
Using a resume token with a different target is unsupported and may fail.
Implementation
final Uint8List? resumeToken;
A resume token from a prior
TargetChange for an identical target.
Using a resume token with a different target is unsupported and may fail.
final Uint8List? resumeToken;