cause property
Status?
cause
final
The error that resulted in this change, if applicable.
Implementation
final Status? cause;
The error that resulted in this change, if applicable.
final Status? cause;