resumeToken property
A token that can be used to resume the stream for the given target_ids,
or all targets if target_ids is empty.
Not set on every target change.
Implementation
final Uint8List resumeToken;
A token that can be used to resume the stream for the given target_ids,
or all targets if target_ids is empty.
Not set on every target change.
final Uint8List resumeToken;