TransactionOptions class final
Options for creating a new transaction.
Constructors
- TransactionOptions({TransactionOptions_ReadOnly? readOnly, TransactionOptions_ReadWrite? readWrite})
- TransactionOptions.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readOnly → TransactionOptions_ReadOnly?
-
The transaction can only be used for read operations.
final
- readWrite → TransactionOptions_ReadWrite?
-
The transaction can be used for both read and write operations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String