readWrite property
The transaction can be used for both read and write operations.
Implementation
final TransactionOptions_ReadWrite? readWrite;
The transaction can be used for both read and write operations.
final TransactionOptions_ReadWrite? readWrite;