TransactionOptions_ConcurrencyMode class final

The type of concurrency control mode for transactions.

Properties

hashCode int
The hash code for this object.
no setterinherited
isNotDefault bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object?
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

$default → const TransactionOptions_ConcurrencyMode
The default value for TransactionOptions_ConcurrencyMode.
concurrencyModeUnspecified → const TransactionOptions_ConcurrencyMode
Start the transaction with the database-level default concurrency mode.
optimistic → const TransactionOptions_ConcurrencyMode
Use optimistic concurrency control for the new transaction.
pessimistic → const TransactionOptions_ConcurrencyMode
Use pessimistic concurrency control for the new transaction.