UpdateDocumentRequest class final

The request for Firestore.UpdateDocument.

Constructors

UpdateDocumentRequest({required Document? document, DocumentMask? updateMask, DocumentMask? mask, Precondition? currentDocument})
UpdateDocumentRequest.fromJson(Object? j)
factory

Properties

currentDocument Precondition?
An optional precondition on the document. The request will fail if this is set and not met by the target document.
final
document Document?
Required. The updated document. Creates the document if it does not already exist.
final
hashCode int
The hash code for this object.
no setterinherited
mask DocumentMask?
The fields to return. If not set, returns all fields.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateMask DocumentMask?
The fields to update. None of the field paths in the mask may contain a reserved name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String