document property
Required. The updated document. Creates the document if it does not already exist.
Implementation
final Document? document;
Required. The updated document. Creates the document if it does not already exist.
final Document? document;