Value class final

A message that can hold any of the supported value types.

Constructors

Value({NullValue? nullValue, bool? booleanValue, int? integerValue, double? doubleValue, Timestamp? timestampValue, String? stringValue, Uint8List? bytesValue, String? referenceValue, LatLng? geoPointValue, ArrayValue? arrayValue, MapValue? mapValue, String? fieldReferenceValue, String? variableReferenceValue, Function$? functionValue, Pipeline? pipelineValue})
Value.fromJson(Object? j)
factory

Properties

arrayValue ArrayValue?
An array value.
final
booleanValue bool?
A boolean value.
final
bytesValue Uint8List?
A bytes value.
final
doubleValue double?
A double value.
final
fieldReferenceValue String?
Value which references a field.
final
functionValue Function$?
A value that represents an unevaluated expression.
final
geoPointValue → LatLng?
A geo point value representing a point on the surface of Earth.
final
hashCode int
The hash code for this object.
no setterinherited
integerValue int?
An integer value.
final
mapValue MapValue?
A map value.
final
nullValue → NullValue?
A null value.
final
pipelineValue Pipeline?
A value that represents an unevaluated pipeline.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
referenceValue String?
A reference to a document. For example: projects/{project_id}/databases/{database_id}/documents/{document_path}.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringValue String?
A string value.
final
timestampValue → Timestamp?
A timestamp value.
final
variableReferenceValue String?
Pointer to a variable defined elsewhere in a pipeline.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String