arrayValue property
An array value.
Cannot directly contain another array value, though can contain a map which contains another array.
Implementation
final ArrayValue? arrayValue;
An array value.
Cannot directly contain another array value, though can contain a map which contains another array.
final ArrayValue? arrayValue;