Write class final

A write on a document.

Constructors

Write({Document? update, String? delete, DocumentTransform? transform, DocumentMask? updateMask, List<DocumentTransform_FieldTransform> updateTransforms = const [], Precondition? currentDocument})
Write.fromJson(Object? j)
factory

Properties

currentDocument Precondition?
An optional precondition on the document.
final
delete String?
A document name to delete. In the format: projects/{project_id}/databases/{database_id}/documents/{document_path}.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transform DocumentTransform?
Applies a transformation to a document.
final
update Document?
A document to write.
final
updateMask DocumentMask?
The fields to update in this write.
final
updateTransforms List<DocumentTransform_FieldTransform>
The transforms to perform after update.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String