currentDocument property
An optional precondition on the document.
The write will fail if this is set and not met by the target document.
Implementation
final Precondition? currentDocument;
An optional precondition on the document.
The write will fail if this is set and not met by the target document.
final Precondition? currentDocument;