WriteRequest class final

The request for Firestore.Write.

The first request creates a stream, or resumes an existing one from a token.

When creating a new stream, the server replies with a response containing only an ID and a token, to use in the next request.

When resuming a stream, the server first streams any responses later than the given token, then a response containing only an up-to-date token, to use in the next request.

Constructors

WriteRequest({required String database, String streamId = '', List<Write> writes = const [], Uint8List? streamToken, Map<String, String> labels = const {}, RequestOptions? requestOptions})
WriteRequest.fromJson(Object? j)
factory

Properties

database → String
Required. The database name. In the format: projects/{project_id}/databases/{database_id}. This is only required in the first message.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → Map<String, String>
Labels associated with this write request.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestOptions → RequestOptions?
Optional. Any additional options for the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamId → String
The ID of the write stream to resume. This may only be set in the first message. When left empty, a new write stream will be created.
final
streamToken → Uint8List
A stream token that was previously sent by the server.
final
writes → List<Write>
The writes to apply.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String