WriteResult class final

The result of applying a write.

Constructors

WriteResult({Timestamp? updateTime, List<Value> transformResults = const []})
WriteResult.fromJson(Object? j)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transformResults List<Value>
The results of applying each DocumentTransform.FieldTransform, in the same order.
final
updateTime → Timestamp?
The last update time of the document after applying the write. Not set after a delete.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String