updateTime property

Timestamp? updateTime
final

The last update time of the document after applying the write. Not set after a delete.

If the write did not actually change the document, this will be the previous update_time.

Implementation

final Timestamp? updateTime;