partitionQuery method

  1. @override
Future<PartitionQueryResponse> partitionQuery(
  1. PartitionQueryRequest request
)
override

Partitions a query by returning partition cursors that can be used to run the query in parallel. The returned partition cursors are split points that can be used by RunQuery as starting/end points for the query results.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<PartitionQueryResponse> partitionQuery(
  PartitionQueryRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_partitionQuery case final partitionQuery?) {
    return partitionQuery(request);
  }
  throw UnsupportedError('partitionQuery');
}