firestore library
The Google Cloud client for the Cloud Firestore API.
Accesses the NoSQL document database built for automatic scaling, high performance, and ease of application development.
Classes
- AggregationResult
- The result of a single bucket from a Firestore aggregation query.
- ArrayValue
- An array value.
- BatchGetDocumentsRequest
-
The request for
Firestore.BatchGetDocuments. - BatchGetDocumentsResponse
-
The streamed response for
Firestore.BatchGetDocuments. - BatchWriteRequest
-
The request for
Firestore.BatchWrite. - BatchWriteResponse
-
The response from
Firestore.BatchWrite. - BeginTransactionRequest
-
The request for
Firestore.BeginTransaction. - BeginTransactionResponse
-
The response for
Firestore.BeginTransaction. - BitSequence
- A sequence of bits, encoded in a byte array.
- BloomFilter
- A bloom filter (https://en.wikipedia.org/wiki/Bloom_filter).
- CommitRequest
-
The request for
Firestore.Commit. - CommitResponse
-
The response for
Firestore.Commit. - CreateDocumentRequest
-
The request for
Firestore.CreateDocument. - Cursor
- A position in a query result set.
- DeleteDocumentRequest
-
The request for
Firestore.DeleteDocument. - Document
- A Firestore document.
- DocumentChange
-
A
Documenthas changed. - DocumentDelete
-
A
Documenthas been deleted. - DocumentMask
-
A set of field paths on a document.
Used to restrict a get or update operation on a document to a subset of its
fields.
This is different from standard field masks, as this is always scoped to a
Document, and takes in account the dynamic nature ofValue. - DocumentRemove
-
A
Documenthas been removed from the view of the targets. - DocumentTransform
- A transformation of a document.
- DocumentTransform_FieldTransform
- A transformation of a field of the document.
- DocumentTransform_FieldTransform_ServerValue
- A value that is calculated by the server.
- ExecutePipelineRequest
-
The request for
Firestore.ExecutePipeline. - ExecutePipelineResponse
-
The response for
Firestore.Execute. - ExecutionStats
- Execution statistics for the query.
- ExistenceFilter
- A digest of all the documents that match a given target.
- ExplainMetrics
- Explain metrics for the query.
- ExplainOptions
- Explain options for the query.
- ExplainStats
- Pipeline explain stats.
- Firestore
- The Cloud Firestore service.
- Function$
- Represents an unevaluated scalar expression.
- GetDocumentRequest
-
The request for
Firestore.GetDocument. - ListCollectionIdsRequest
-
The request for
Firestore.ListCollectionIds. - ListCollectionIdsResponse
-
The response from
Firestore.ListCollectionIds. - ListDocumentsRequest
-
The request for
Firestore.ListDocuments. - ListDocumentsResponse
-
The response for
Firestore.ListDocuments. - ListenRequest
-
A request for
Firestore.Listen - ListenResponse
-
The response for
Firestore.Listen. - MapValue
- A map value.
- PartitionQueryRequest
-
The request for
Firestore.PartitionQuery. - PartitionQueryResponse
-
The response for
Firestore.PartitionQuery. - Pipeline
- A Firestore query represented as an ordered list of operations / stages.
- Pipeline_Stage
- A single operation within a pipeline.
- PlanSummary
- Planning phase information for the query.
- Precondition
- A precondition on a document, used for conditional operations.
- RollbackRequest
-
The request for
Firestore.Rollback. - RunAggregationQueryRequest
-
The request for
Firestore.RunAggregationQuery. - RunAggregationQueryResponse
-
The response for
Firestore.RunAggregationQuery. - RunQueryRequest
-
The request for
Firestore.RunQuery. - RunQueryResponse
-
The response for
Firestore.RunQuery. - StructuredAggregationQuery
-
Firestore query for running an aggregation over a
StructuredQuery. - StructuredAggregationQuery_Aggregation
- Defines an aggregation that produces a single result.
- StructuredAggregationQuery_Aggregation_Avg
- Average of the values of the requested field.
- StructuredAggregationQuery_Aggregation_Count
- Count of documents that match the query.
- StructuredAggregationQuery_Aggregation_Sum
- Sum of the values of the requested field.
- StructuredPipeline
- A Firestore query represented as an ordered list of operations / stages.
- StructuredQuery
- A Firestore query.
- StructuredQuery_CollectionSelector
-
A selection of a collection, such as
messages as m1. - StructuredQuery_CompositeFilter
- A filter that merges multiple other filters using the given operator.
- StructuredQuery_CompositeFilter_Operator
- A composite filter operator.
- StructuredQuery_Direction
- A sort direction.
- StructuredQuery_FieldFilter
- A filter on a specific field.
- StructuredQuery_FieldFilter_Operator
- A field filter operator.
- StructuredQuery_FieldReference
-
A reference to a field in a document, ex:
stats.operations. - StructuredQuery_Filter
- A filter.
- StructuredQuery_FindNearest
- Nearest Neighbors search config. The ordering provided by FindNearest supersedes the order_by stage. If multiple documents have the same vector distance, the returned document order is not guaranteed to be stable between queries.
- StructuredQuery_FindNearest_DistanceMeasure
- The distance measure to use when comparing vectors.
- StructuredQuery_Order
- An order on a field.
- StructuredQuery_Projection
- The projection of document's fields to return.
- StructuredQuery_UnaryFilter
- A filter with a single operand.
- StructuredQuery_UnaryFilter_Operator
- A unary operator.
- Target
- A specification of a set of documents to listen to.
- Target_DocumentsTarget
- A target specified by a set of documents names.
- Target_QueryTarget
- A target specified by a query.
- TargetChange
- Targets being watched have changed.
- TargetChange_TargetChangeType
- The type of change.
- TransactionOptions
- Options for creating a new transaction.
- TransactionOptions_ReadOnly
- Options for a transaction that can only be used to read documents.
- TransactionOptions_ReadWrite
- Options for a transaction that can be used to read and write documents.
- UpdateDocumentRequest
-
The request for
Firestore.UpdateDocument. - Value
- A message that can hold any of the supported value types.
- Write
- A write on a document.
- WriteRequest
-
The request for
Firestore.Write. - WriteResponse
-
The response for
Firestore.Write. - WriteResult
- The result of applying a write.