aggregateFields property
The result of the aggregation functions, ex: COUNT(*) AS total_docs.
The key is the
alias
assigned to the aggregation function on input and the size of this map
equals the number of aggregation functions in the query.
Implementation
final Map<String, Value> aggregateFields;