BatchGetDocumentsRequest class final

The request for Firestore.BatchGetDocuments.

Constructors

BatchGetDocumentsRequest({required String database, List<String> documents = const [], DocumentMask? mask, Uint8List? transaction, TransactionOptions? newTransaction, Timestamp? readTime})
BatchGetDocumentsRequest.fromJson(Object? j)
factory

Properties

database String
Required. The database name. In the format: projects/{project_id}/databases/{database_id}.
final
documents List<String>
The names of the documents to retrieve. In the format: projects/{project_id}/databases/{database_id}/documents/{document_path}. The request will fail if any of the document is not a child resource of the given database. Duplicate names will be elided.
final
hashCode int
The hash code for this object.
no setterinherited
mask DocumentMask?
The fields to return. If not set, returns all fields.
final
newTransaction TransactionOptions?
Starts a new transaction and reads the documents. Defaults to a read-only transaction. The new transaction ID will be returned as the first response in the stream.
final
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
readTime → Timestamp?
Reads documents as they were at the given time.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction Uint8List?
Reads documents in a transaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String