BatchGetDocumentsResponse class final
The streamed response for
Firestore.BatchGetDocuments.
Constructors
- BatchGetDocumentsResponse({Document? found, String? missing, Uint8List? transaction, Timestamp? readTime})
- BatchGetDocumentsResponse.fromJson(Object? j)
-
factory
Properties
- found → Document?
-
A document that was requested.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- missing → String?
-
A document name that was requested but does not exist. In the format:
projects/{project_id}/databases/{database_id}/documents/{document_path}.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
The time at which the document was read.
This may be monotically increasing, in this case the previous documents in
the result stream are guaranteed not to have changed between their
read_time and this one.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction → Uint8List
-
The transaction that was started as part of this request.
Will only be set in the first response, and only if
BatchGetDocumentsRequest.new_transactionwas set in the request.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String