transaction property
The transaction that was started as part of this request.
Will only be set in the first response, and only if
BatchGetDocumentsRequest.new_transaction
was set in the request.
Implementation
final Uint8List transaction;
The transaction that was started as part of this request.
Will only be set in the first response, and only if
BatchGetDocumentsRequest.new_transaction
was set in the request.
final Uint8List transaction;