BatchWriteResponse class final
The response from
Firestore.BatchWrite.
Constructors
-
BatchWriteResponse({List<
WriteResult> writeResults = const [], List<Status> status = const []}) - BatchWriteResponse.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ List<
Status> -
The status of applying the writes.
final
-
writeResults
→ List<
WriteResult> -
The result of applying the writes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String