CommitRequest class final
The request for Firestore.Commit.
Constructors
-
CommitRequest({required String database, List<
Write> writes = const [], Uint8List? transaction}) - CommitRequest.fromJson(Object? j)
-
factory
Properties
- database → String
-
Required. The database name. In the format:
projects/{project_id}/databases/{database_id}.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction → Uint8List
-
If set, applies all writes in this transaction, and commits it.
final
-
writes
→ List<
Write> -
The writes to apply.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String