CommitResponse class final
The response for Firestore.Commit.
Constructors
-
CommitResponse({List<
WriteResult> writeResults = const [], Timestamp? commitTime}) - CommitResponse.fromJson(Object? j)
-
factory
Properties
- commitTime → Timestamp?
-
The time at which the commit occurred. Any read with an equal or greater
read_timeis guaranteed to see the effects of the commit.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
writeResults
→ List<
WriteResult> -
The result of applying the writes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String