DeleteDocumentRequest class final
The request for
Firestore.DeleteDocument.
Constructors
- DeleteDocumentRequest({required String name, Precondition? currentDocument})
- DeleteDocumentRequest.fromJson(Object? j)
-
factory
Properties
- currentDocument → Precondition?
-
An optional precondition on the document.
The request will fail if this is set and not met by the target document.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Required. The resource name of the Document to delete. In the format:
projects/{project_id}/databases/{database_id}/documents/{document_path}.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String