DocumentChange class final
A Document has changed.
May be the result of multiple writes, including
deletes, that ultimately resulted in a new value for the
Document.
Multiple DocumentChange messages may be
returned for the same logical change, if multiple targets are affected.
Constructors
-
DocumentChange({Document? document, List<
int> targetIds = const [], List<int> removedTargetIds = const []}) - DocumentChange.fromJson(Object? j)
-
factory
Properties
- document → Document?
-
The new state of the
Document.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
removedTargetIds
→ List<
int> -
A set of target IDs for targets that no longer match this document.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
targetIds
→ List<
int> -
A set of target IDs of targets that match this document.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String