DocumentMask class final
A set of field paths on a document.
Used to restrict a get or update operation on a document to a subset of its
fields.
This is different from standard field masks, as this is always scoped to a
Document, and takes in account the dynamic
nature of Value.
Constructors
-
DocumentMask({List<
String> fieldPaths = const []}) - DocumentMask.fromJson(Object? j)
-
factory
Properties
-
fieldPaths
→ List<
String> -
The list of field paths in the mask. See
Document.fieldsfor a field path syntax reference.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String