DocumentRemove class final
A Document has been removed from the view of
the targets.
Sent if the document is no longer relevant to a target and is out of view. Can be sent instead of a DocumentDelete or a DocumentChange if the server can not send the new value of the document.
Multiple DocumentRemove messages may be
returned for the same logical write or delete, if multiple targets are
affected.
Constructors
-
DocumentRemove({String document = '', List<
int> removedTargetIds = const [], Timestamp? readTime}) - DocumentRemove.fromJson(Object? j)
-
factory
Properties
- document → String
-
The resource name of the
Documentthat has gone out of view.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
The read timestamp at which the remove was observed.
final
-
removedTargetIds
→ List<
int> -
A set of target IDs for targets that previously matched this document.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String