ExecutePipelineRequest class final
The request for
Firestore.ExecutePipeline.
Constructors
- ExecutePipelineRequest({required String database, StructuredPipeline? structuredPipeline, Uint8List? transaction, TransactionOptions? newTransaction, Timestamp? readTime})
- ExecutePipelineRequest.fromJson(Object? j)
-
factory
Properties
- database → String
-
Required. Database identifier, in the form
projects/{project}/databases/{database}.final - hashCode → int
-
The hash code for this object.
no setterinherited
- newTransaction → TransactionOptions?
-
Execute the pipeline in a new transaction.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
Execute the pipeline in a snapshot transaction at the given time.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structuredPipeline → StructuredPipeline?
-
A pipelined operation.
final
- transaction → Uint8List?
-
Run the query within an already active transaction.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String