ExecutePipelineResponse class final
The response for Firestore.Execute.
Constructors
-
ExecutePipelineResponse({Uint8List? transaction, List<
Document> results = const [], Timestamp? executionTime, ExplainStats? explainStats}) - ExecutePipelineResponse.fromJson(Object? j)
-
factory
Properties
- executionTime → Timestamp?
-
The time at which the results are valid.
final
- explainStats → ExplainStats?
-
Query explain stats.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited -
results
→ List<
Document> -
An ordered batch of results returned executing a pipeline.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction → Uint8List
-
Newly created transaction identifier.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String