executionTime property
Timestamp?
executionTime
final
The time at which the results are valid.
This is a (not strictly) monotonically increasing value across multiple
responses in the same stream. The API guarantees that all previously
returned results are still valid at the latest execution_time. This
allows the API consumer to treat the query if it ran at the latest
execution_time returned.
If the query returns no results, a response with execution_time and no
results will be sent, and this represents the time at which the operation
was run.
Implementation
final Timestamp? executionTime;