transaction property
Newly created transaction identifier.
This field is only specified as part of the first response from the server,
alongside the results field when the original request specified
ExecuteRequest.new_transaction.
Implementation
final Uint8List transaction;