ExecutionStats class final
Execution statistics for the query.
Constructors
- ExecutionStats({int resultsReturned = 0, Duration? executionDuration, int readOperations = 0, Struct? debugStats})
- ExecutionStats.fromJson(Object? j)
-
factory
Properties
- debugStats → Struct?
-
Debugging statistics from the execution of the query. Note that the
debugging stats are subject to change as Firestore evolves. It could
include:
{
"indexes_entries_scanned": "1000",
"documents_scanned": "20",
"billing_details" : {
"documents_billable": "20",
"index_entries_billable": "1000",
"min_query_cost": "0"
}
}
final
- executionDuration → Duration?
-
Total time to execute the query in the backend.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readOperations → int
-
Total billable read operations.
final
- resultsReturned → int
-
Total number of results returned, including documents, projections,
aggregation results, keys.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String