batchGetDocuments method
Gets multiple documents.
Documents returned by this method are not guaranteed to be returned in the same order that they were requested.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Stream<BatchGetDocumentsResponse> batchGetDocuments(
BatchGetDocumentsRequest request,
) {
final url = _endPoint.replace(
path: '/v1/${request.database}/documents:batchGet',
);
return _client
.postStreaming(url, body: request, enableSse: false)
.map(BatchGetDocumentsResponse.fromJson);
}