partitionQuery method
Partitions a query by returning partition cursors that can be used to run the query in parallel. The returned partition cursors are split points that can be used by RunQuery as starting/end points for the query results.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<PartitionQueryResponse> partitionQuery(
PartitionQueryRequest request,
) async {
final url = _endPoint.replace(path: '/v1/${request.parent}:partitionQuery');
final response = await _client.post(url, body: request);
return PartitionQueryResponse.fromJson(response);
}