GetDocumentRequest class final
The request for
Firestore.GetDocument.
Constructors
- GetDocumentRequest({required String name, DocumentMask? mask, Uint8List? transaction, Timestamp? readTime})
- GetDocumentRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mask → DocumentMask?
-
The fields to return. If not set, returns all fields.
final
- name → String
-
Required. The resource name of the Document to get. In the format:
projects/{project_id}/databases/{database_id}/documents/{document_path}.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
Reads the version of the document at the given time.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction → Uint8List?
-
Reads the document in a transaction.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String