PartitionQueryRequest class final
The request for
Firestore.PartitionQuery.
Constructors
- PartitionQueryRequest({required String parent, StructuredQuery? structuredQuery, int partitionCount = 0, String pageToken = '', int pageSize = 0, Timestamp? readTime})
- PartitionQueryRequest.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageSize → int
-
The maximum number of partitions to return in this call, subject to
partition_count.final - pageToken → String
-
The
next_page_tokenvalue returned from a previous call to PartitionQuery that may be used to get an additional set of results. There are no ordering guarantees between sets of results. Thus, using multiple sets of results will require merging the different result sets.final - parent → String
-
Required. The parent resource name. In the format:
projects/{project_id}/databases/{database_id}/documents. Document resource names are not supported; only database resource names can be specified.final - partitionCount → int
-
The desired maximum number of partition points.
The partitions may be returned across multiple pages of results.
The number must be positive. The actual number of partitions
returned may be fewer.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
Reads documents as they were at the given time.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structuredQuery → StructuredQuery?
-
A structured query.
Query must specify collection with all descendants and be ordered by name
ascending. Other filters, order bys, limits, offsets, and start/end
cursors are not supported.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String