PartitionQueryResponse class final
The response for
Firestore.PartitionQuery.
Constructors
-
PartitionQueryResponse({List<
Cursor> partitions = const [], String nextPageToken = ''}) - PartitionQueryResponse.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken → String
-
A page token that may be used to request an additional set of results, up
to the number specified by
partition_countin the PartitionQuery request. If blank, there are no more results.final -
partitions
→ List<
Cursor> -
Partition results.
Each partition is a split point that can be used by RunQuery as a starting
or end point for the query results. The RunQuery requests must be made with
the same query supplied to this PartitionQuery request. The partition
cursors will be ordered according to same ordering as the results of the
query supplied to PartitionQuery.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String