Precondition class final
A precondition on a document, used for conditional operations.
Constructors
- Precondition({bool? exists, Timestamp? updateTime})
- Precondition.fromJson(Object? j)
-
factory
Properties
- exists → bool?
-
When set to
true, the target document must exist. When set tofalse, the target document must not exist.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateTime → Timestamp?
-
When set, the target document must exist and have been last updated at
that time. Timestamp must be microsecond aligned.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String