RollbackRequest class final

The request for Firestore.Rollback.

Constructors

RollbackRequest({required String database, required Uint8List transaction, RequestOptions? requestOptions})
RollbackRequest.fromJson(Object? j)
factory

Properties

database String
Required. The database name. In the format: projects/{project_id}/databases/{database_id}.
final
hashCode int
The hash code for this object.
no setterinherited
qualifiedName String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
requestOptions RequestOptions?
Optional. Any additional options for the request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction Uint8List
Required. The transaction to roll back.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String