RunAggregationQueryRequest class final
The request for
Firestore.RunAggregationQuery.
Constructors
- RunAggregationQueryRequest({required String parent, StructuredAggregationQuery? structuredAggregationQuery, Uint8List? transaction, TransactionOptions? newTransaction, Timestamp? readTime, ExplainOptions? explainOptions})
- RunAggregationQueryRequest.fromJson(Object? j)
-
factory
Properties
- explainOptions → ExplainOptions?
-
Optional. Explain options for the query. If set, additional query
statistics will be returned. If not, only query results will be returned.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newTransaction → TransactionOptions?
-
Starts a new transaction as part of the query, defaulting to read-only.
final
- parent → String
-
Required. The parent resource name. In the format:
projects/{project_id}/databases/{database_id}/documentsorprojects/{project_id}/databases/{database_id}/documents/{document_path}. For example:projects/my-project/databases/my-database/documentsorprojects/my-project/databases/my-database/documents/chatrooms/my-chatroomfinal - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
Executes the query at the given timestamp.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structuredAggregationQuery → StructuredAggregationQuery?
-
An aggregation query.
final
- transaction → Uint8List?
-
Run the aggregation within an already active transaction.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String