newTransaction property
Starts a new transaction as part of the query, defaulting to read-only.
The new transaction ID will be returned as the first response in the stream.
Implementation
final TransactionOptions? newTransaction;
Starts a new transaction as part of the query, defaulting to read-only.
The new transaction ID will be returned as the first response in the stream.
final TransactionOptions? newTransaction;