RunAggregationQueryResponse class final
The response for
Firestore.RunAggregationQuery.
Constructors
- RunAggregationQueryResponse({AggregationResult? result, Uint8List? transaction, Timestamp? readTime, ExplainMetrics? explainMetrics})
- RunAggregationQueryResponse.fromJson(Object? j)
-
factory
Properties
- explainMetrics → ExplainMetrics?
-
Query explain metrics. This is only present when the
RunAggregationQueryRequest.explain_optionsis provided, and it is sent only once with the last response in the stream.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
The time at which the aggregate result was computed. This is always
monotonically increasing; in this case, the previous AggregationResult in
the result stream are guaranteed not to have changed between their
read_timeand this one.final - result → AggregationResult?
-
A single aggregation result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction → Uint8List
-
The transaction that was started as part of this request.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String