readTime property
Timestamp?
readTime
final
The time at which the aggregate result was computed. This is always
monotonically increasing; in this case, the previous AggregationResult in
the result stream are guaranteed not to have changed between their
read_time and this one.
If the query returns no results, a response with read_time and no
result will be sent, and this represents the time at which the query
was run.
Implementation
final Timestamp? readTime;