alias property
Optional. Optional name of the field to store the result of the aggregation into.
If not provided, Firestore will pick a default name following the format
field_<incremental_id++>. For example:
AGGREGATE
COUNT_UP_TO(1) AS count_up_to_1,
COUNT_UP_TO(2),
COUNT_UP_TO(3) AS count_up_to_3,
COUNT(*)
OVER (
...
);
becomes:
AGGREGATE
COUNT_UP_TO(1) AS count_up_to_1,
COUNT_UP_TO(2) AS field_1,
COUNT_UP_TO(3) AS count_up_to_3,
COUNT(*) AS field_2
OVER (
...
);
Requires:
- Must be unique across all aggregation aliases.
- Conform to
google.firestore.v1.Document.fieldslimitations.
Implementation
final String alias;