upTo property
Int64Value?
upTo
final
Optional. Optional constraint on the maximum number of documents to count.
This provides a way to set an upper bound on the number of documents to scan, limiting latency, and cost.
Unspecified is interpreted as no bound.
High-Level Example:
AGGREGATE COUNT_UP_TO(1000) OVER ( SELECT * FROM k );
Requires:
- Must be greater than zero when present.
Implementation
final Int64Value? upTo;