offset property
The number of documents to skip before returning the first result.
This applies after the constraints specified by the WHERE, START AT, &
END AT but before the LIMIT clause.
Requires:
- The value must be greater than or equal to zero if specified.
Implementation
final int offset;