StructuredQuery_CollectionSelector class final
A selection of a collection, such as messages as m1.
Constructors
- StructuredQuery_CollectionSelector({String collectionId = '', bool allDescendants = false})
- StructuredQuery_CollectionSelector.fromJson(Object? j)
-
factory
Properties
- allDescendants → bool
-
When false, selects only collections that are immediate children of
the
parentspecified in the containingRunQueryRequest. When true, selects all descendant collections.final - collectionId → String
-
The collection ID.
When set, selects only collections with this ID.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String