cosine constant
StructuredQuery_FindNearest_DistanceMeasure
const cosine
COSINE distance compares vectors based on the angle between them, which allows you to measure similarity that isn't based on the vectors magnitude. We recommend using DOT_PRODUCT with unit normalized vectors instead of COSINE distance, which is mathematically equivalent with better performance. See Cosine Similarity to learn more about COSINE similarity and COSINE distance. The resulting COSINE distance decreases the more similar two vectors are.
Implementation
static const cosine = StructuredQuery_FindNearest_DistanceMeasure('COSINE');