TargetChange class final
Targets being watched have changed.
Constructors
-
TargetChange({TargetChange_TargetChangeType targetChangeType = TargetChange_TargetChangeType.$default, List<
int> targetIds = const [], Status? cause, Uint8List? resumeToken, Timestamp? readTime}) - TargetChange.fromJson(Object? j)
-
factory
Properties
- cause → Status?
-
The error that resulted in this change, if applicable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - readTime → Timestamp?
-
The consistent
read_timefor the giventarget_ids(omitted when the target_ids are not at a consistent snapshot).final - resumeToken → Uint8List
-
A token that can be used to resume the stream for the given
target_ids, or all targets iftarget_idsis empty.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetChangeType → TargetChange_TargetChangeType
-
The type of change that occurred.
final
-
targetIds
→ List<
int> -
The target IDs of targets that have changed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String