Target_DocumentsTarget class final
A target specified by a set of documents names.
Constructors
-
Target_DocumentsTarget({List<
String> documents = const []}) - Target_DocumentsTarget.fromJson(Object? j)
-
factory
Properties
-
documents
→ List<
String> -
The names of the documents to retrieve. In the format:
projects/{project_id}/databases/{database_id}/documents/{document_path}. The request will fail if any of the document is not a child resource of the givendatabase. Duplicate names will be elided.final - hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String