Target_QueryTarget class final
A target specified by a query.
Constructors
- Target_QueryTarget({String parent = '', StructuredQuery? structuredQuery})
- Target_QueryTarget.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent → String
-
The parent resource name. In the format:
projects/{project_id}/databases/{database_id}/documentsorprojects/{project_id}/databases/{database_id}/documents/{document_path}. For example:projects/my-project/databases/my-database/documentsorprojects/my-project/databases/my-database/documents/chatrooms/my-chatroomfinal - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structuredQuery → StructuredQuery?
-
A structured query.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String