concurrencyMode property
Optional. The concurrency control mode to use for this transaction.
A database is able to use different concurrency modes for different transactions simultaneously.
3rd party auth requests are only allowed to create optimistic read-write transactions and must specify that here even if the database-level setting is already configured to optimistic.
Implementation
final TransactionOptions_ConcurrencyMode concurrencyMode;