variableReferenceValue property
Pointer to a variable defined elsewhere in a pipeline.
Unlike field_reference_value which references a field within a
document, this refers to a variable, defined in a separate namespace than
the fields of a document.
Implementation
final String? variableReferenceValue;