streamId property
The ID of the write stream to resume. This may only be set in the first message. When left empty, a new write stream will be created.
Implementation
final String streamId;
The ID of the write stream to resume. This may only be set in the first message. When left empty, a new write stream will be created.
final String streamId;