streamToken property
A token that represents the position of this response in the stream. This can be used by a client to resume the stream at this point.
This field is always set.
Implementation
final Uint8List streamToken;
A token that represents the position of this response in the stream. This can be used by a client to resume the stream at this point.
This field is always set.
final Uint8List streamToken;