batchGetDocuments method
Gets multiple documents.
Documents returned by this method are not guaranteed to be returned in the same order that they were requested.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Stream<BatchGetDocumentsResponse> batchGetDocuments(
BatchGetDocumentsRequest request,
) {
if (isClosed) throw StateError('Service is closed');
if (_batchGetDocuments case final batchGetDocuments?) {
return batchGetDocuments(request);
}
throw UnsupportedError('batchGetDocuments');
}